# Generated by Django 5.1.5 on 2025-08-20 05:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('tests', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='LazyChoiceModel',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('lazy_choice_field', models.CharField(blank=True, choices=[('C1', 'Lazy Choice One'), ('C2', 'Lazy Choice Two')], help_text='Field with lazy choices', max_length=2, null=True)),
                ('name', models.CharField(default='Test', max_length=50)),
            ],
        ),
        migrations.AlterField(
            model_name='allfieldsmodel',
            name='file_field',
            field=models.FileField(blank=True, null=True, upload_to='uploads/%Y/%m/%d/'),
        ),
        migrations.AlterField(
            model_name='allfieldsmodel',
            name='image_field',
            field=models.ImageField(blank=True, height_field='image_height', null=True, upload_to='images/', width_field='image_width'),
        ),
    ]
