# Generated by Django 5.1.5 on 2025-08-20 06:02

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('tests', '0003_alter_allfieldsmodel_many_to_many_field'),
    ]

    operations = [
        migrations.CreateModel(
            name='ChildType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('conversion_session', models.UUIDField(blank=True, help_text='Links to the conversion session', null=True)),
                ('schema_source', models.CharField(blank=True, help_text='Source XSD file', max_length=255, null=True)),
                ('value', models.CharField(max_length=255)),
                ('code', models.CharField(blank=True, max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ParentType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('conversion_session', models.UUIDField(blank=True, help_text='Links to the conversion session', null=True)),
                ('schema_source', models.CharField(blank=True, help_text='Source XSD file', max_length=255, null=True)),
                ('owner', models.CharField(max_length=255)),
                ('child', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='tests.childtype')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ItemType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('conversion_session', models.UUIDField(blank=True, help_text='Links to the conversion session', null=True)),
                ('schema_source', models.CharField(blank=True, help_text='Source XSD file', max_length=255, null=True)),
                ('price', models.DecimalField(decimal_places=2, max_digits=10)),
                ('parenttype', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='items', to='tests.parenttype')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
