# Generated by Django 5.2.5 on 2025-08-29 21:39

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("tests", "0006_childtype_parenttype_itemtype"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="parenttype",
            name="child",
        ),
        migrations.RemoveField(
            model_name="itemtype",
            name="parenttype",
        ),
        migrations.DeleteModel(
            name="ChildType",
        ),
        migrations.DeleteModel(
            name="ItemType",
        ),
        migrations.DeleteModel(
            name="ParentType",
        ),
    ]
